Learn R Programming

AtmChile (version 1.2.0)

ChileAirQualityApp: Title ChileAirQualityApp

Description

This tool is a dashboard that allows you to use the data download functions of this package enhanced with analysis, visualization and descriptive statistics tools.

Usage

ChileAirQualityApp()

Arguments

Value

A shiny dashboard to work with the package

See Also

<https://chileairquality.shinyapps.io/chileairquality/>

Examples

Run this code
if (FALSE) ChileAirQualityApp()

Run the code above in your browser using DataLab