powered by
This tool is a dashboard that allows you to use the data download functions of this package enhanced with analysis, visualization and descriptive statistics tools.
ChileAirQualityApp()
A shiny dashboard to work with the package
<https://chileairquality.shinyapps.io/chileairquality/>
if (FALSE) ChileAirQualityApp()
Run the code above in your browser using DataLab